import OSLog
from PyObjCTools.TestSupport import TestCase


class TestEntryLog(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogEntryLogLevel)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogEntryLogLevelUndefined, 0)
        self.assertEqual(OSLog.OSLogEntryLogLevelDebug, 1)
        self.assertEqual(OSLog.OSLogEntryLogLevelInfo, 2)
        self.assertEqual(OSLog.OSLogEntryLogLevelNotice, 3)
        self.assertEqual(OSLog.OSLogEntryLogLevelError, 4)
        self.assertEqual(OSLog.OSLogEntryLogLevelFault, 5)



import OSLog
from PyObjCTools.TestSupport import TestCase


class TestEntrySignpost(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogEntrySignpostType)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogEntrySignpostTypeUndefined, 0)
        self.assertEqual(OSLog.OSLogEntrySignpostTypeIntervalBegin, 1)
        self.assertEqual(OSLog.OSLogEntrySignpostTypeIntervalEnd, 2)
        self.assertEqual(OSLog.OSLogEntrySignpostTypeEvent, 3)



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 19:11:35 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$OSLogEntryLogLevelDebug@1$OSLogEntryLogLevelError@4$OSLogEntryLogLevelFault@5$OSLogEntryLogLevelInfo@2$OSLogEntryLogLevelNotice@3$OSLogEntryLogLevelUndefined@0$OSLogEntrySignpostTypeEvent@3$OSLogEntrySignpostTypeIntervalBegin@1$OSLogEntrySignpostTypeIntervalEnd@2$OSLogEntrySignpostTypeUndefined@0$OSLogEntryStoreCategoryLongTerm1@4$OSLogEntryStoreCategoryLongTerm14@7$OSLogEntryStoreCategoryLongTerm3@5$OSLogEntryStoreCategoryLongTerm30@8$OSLogEntryStoreCategoryLongTerm7@6$OSLogEntryStoreCategoryLongTermAuto@3$OSLogEntryStoreCategoryMetadata@1$OSLogEntryStoreCategoryShortTerm@2$OSLogEntryStoreCategoryUndefined@0$OSLogEnumeratorReverse@1$OSLogMessageComponentArgumentCategoryData@1$OSLogMessageComponentArgumentCategoryDouble@2$OSLogMessageComponentArgumentCategoryInt64@3$OSLogMessageComponentArgumentCategoryString@4$OSLogMessageComponentArgumentCategoryUInt64@5$OSLogMessageComponentArgumentCategoryUndefined@0$OSLogStoreCurrentProcessIdentifier@1$OSLogStoreSystem@0$"""
misc.update(
    {
        "OSLogMessageComponentArgumentCategory": NewType(
            "OSLogMessageComponentArgumentCategory", int
        ),
        "OSLogEnumeratorOptions": NewType("OSLogEnumeratorOptions", int),
        "OSLogEntrySignpostType": NewType("OSLogEntrySignpostType", int),
        "OSLogStoreScope": NewType("OSLogStoreScope", int),
        "OSLogEntryStoreCategory": NewType("OSLogEntryStoreCategory", int),
        "OSLogEntryLogLevel": NewType("OSLogEntryLogLevel", int),
    }
)
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"NSObject", b"activityIdentifier", {"required": True, "retval": {"type": b"Q"}})
    r(b"NSObject", b"category", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"components", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"formatString", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"process", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"processIdentifier", {"required": True, "retval": {"type": b"i"}})
    r(b"NSObject", b"sender", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"subsystem", {"required": True, "retval": {"type": b"@"}})
    r(b"NSObject", b"threadIdentifier", {"required": True, "retval": {"type": b"Q"}})
    r(
        b"OSLogStore",
        b"entriesEnumeratorAndReturnError:",
        {"arguments": {2: {"type_modifier": b"o"}}},
    )
    r(
        b"OSLogStore",
        b"entriesEnumeratorWithOptions:position:predicate:error:",
        {"arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"OSLogStore",
        b"localStoreAndReturnError:",
        {"arguments": {2: {"type_modifier": b"o"}}},
    )
    r(
        b"OSLogStore",
        b"storeWithScope:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"OSLogStore",
        b"storeWithURL:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import OSLog
import objc
from PyObjCTools.TestSupport import TestCase, min_sdk_level


class TestEntryHelper(OSLog.NSObject):
    def activityIdentifier(self):
        return 1

    def processIdentifier(self):
        return 1

    def threadIdentifier(self):
        return 1


class TestEntry(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogEntryStoreCategory)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogEntryStoreCategoryUndefined, 0)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryMetadata, 1)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryShortTerm, 2)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTermAuto, 3)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTerm1, 4)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTerm3, 5)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTerm7, 6)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTerm14, 7)
        self.assertEqual(OSLog.OSLogEntryStoreCategoryLongTerm30, 8)

    def test_methods(self):
        self.assertResultHasType(TestEntryHelper.activityIdentifier, objc._C_NSUInteger)
        self.assertResultHasType(TestEntryHelper.processIdentifier, objc._C_INT)
        self.assertResultHasType(TestEntryHelper.threadIdentifier, objc._C_ULNGLNG)

    @min_sdk_level("10.15")
    def test_protocols(self):
        self.assertProtocolExists("OSLogEntryFromProcess")
        self.assertProtocolExists("OSLogEntryWithPayload")



import OSLog
from PyObjCTools.TestSupport import TestCase


class TestEnumerator(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogEnumeratorOptions)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogEnumeratorReverse, 0x01)



import OSLog
from PyObjCTools.TestSupport import TestCase


class TestMessageComponent(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogMessageComponentArgumentCategory)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryUndefined, 0)
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryData, 1)
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryDouble, 2)
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryInt64, 3)
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryString, 4)
        self.assertEqual(OSLog.OSLogMessageComponentArgumentCategoryUInt64, 5)



import OSLog
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestStore(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(OSLog.OSLogStoreScope)

    def test_constants(self):
        self.assertEqual(OSLog.OSLogStoreSystem, 0)
        self.assertEqual(OSLog.OSLogStoreCurrentProcessIdentifier, 1)

    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertArgIsOut(OSLog.OSLogStore.localStoreAndReturnError_, 0)
        self.assertArgIsOut(OSLog.OSLogStore.storeWithURL_error_, 1)
        self.assertArgIsOut(
            OSLog.OSLogStore.entriesEnumeratorWithOptions_position_predicate_error_, 3
        )
        self.assertArgIsOut(OSLog.OSLogStore.entriesEnumeratorAndReturnError_, 0)

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsOut(OSLog.OSLogStore.storeWithScope_error_, 1)



"""
Python mapping for the OSLog framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from OSLog import _metadata
from OSLog import _OSLog

sys.modules["OSLog"] = mod = objc.ObjCLazyModule(
    "OSLog",
    "com.apple.OSLog",
    objc.pathForFramework("/System/Library/Frameworks/OSLog.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_OSLog, Foundation),
)


del sys.modules["OSLog._metadata"]
